declare enum ProtocolEnum {
    ARWEAVE = "arweave",
    FILECOIN = "ipfs-filecoin",
    IPFS = "ipfs"
}

interface UploadResult {
    uploadId: string;
    bucketId: string;
    protocolLink: string;
    dynamicLinks: string[];
}

declare enum ProjectStateEnum {
    MAINTAINED = "MAINTAINED",
    ARCHIVED = "ARCHIVED"
}
declare enum DomainTypeEnum {
    DOMAIN = "domain",
    SUBDOMAIN = "subdomain",
    HANDSHAKE_DOMAIN = "handshake-domain",
    HANDSHAKE_SUBDOMAIN = "handshake-subdomain",
    ENS_DOMAIN = "ens-domain"
}

interface Domain {
    id: string;
    name: string;
    link: string;
    verified: boolean;
    bucketId: string;
    type: DomainTypeEnum;
}
type BucketStateEnum = ProjectStateEnum;
interface Bucket {
    id: string;
    name: string;
    organizationId: string;
    state: BucketStateEnum;
    domains: Domain[];
}
declare enum UploadStatusEnum {
    PENDING = "Pending",
    CANCELED = "Canceled",
    DEPLOYED = "Deployed",
    FAILED = "Failed",
    TIMED_OUT = "TimedOut"
}
interface Upload {
    id: string;
    protocolLink: string;
    buildDirectory: string[];
    status: UploadStatusEnum;
    memoryUsed: number;
    bucketId: string;
    protocol: string;
}

interface SpheronClientConfiguration {
    token: string;
}
declare class SpheronClient {
    private readonly configuration;
    private readonly spheronApi;
    private readonly bucketManager;
    private readonly uploadManager;
    constructor(configuration: SpheronClientConfiguration);
    upload(path: string, configuration: {
        name: string;
        protocol: ProtocolEnum;
        organizationId?: string;
        onUploadInitiated?: (uploadId: string) => void;
        onChunkUploaded?: (uploadedSize: number, totalSize: number) => void;
    }): Promise<UploadResult>;
    getBucket(bucketId: string): Promise<Bucket>;
    getBucketDomains(bucketId: string): Promise<Domain[]>;
    getBucketDomain(bucketId: string, domainIdentifier: string): Promise<Domain>;
    addBucketDomain(bucketId: string, options: {
        link: string;
        type: DomainTypeEnum | "domain" | "subdomain" | "handshake-domain" | "handshake-subdomain" | "ens-domain";
        name: string;
    }): Promise<Domain>;
    updateBucketDomain(bucketId: string, domainIdentifier: string, options: {
        link: string;
        name: string;
    }): Promise<Domain>;
    verifyBucketDomain(bucketId: string, domainIdentifier: string): Promise<Domain>;
    deleteBucketDomain(bucketId: string, domainIdentifier: string): Promise<void>;
    archiveBucket(bucketId: string): Promise<void>;
    unarchiveBucket(bucketId: string): Promise<void>;
    getBucketUploadCount(bucketId: string): Promise<{
        total: number;
        successful: number;
        failed: number;
        pending: number;
    }>;
    getBucketUploads(bucketId: string, options: {
        skip: number;
        limit: number;
    }): Promise<Upload[]>;
    getUpload(uploadId: string): Promise<Upload>;
}

export { Bucket, BucketStateEnum, Domain, DomainTypeEnum, ProtocolEnum, SpheronClient, SpheronClientConfiguration, Upload, UploadStatusEnum, SpheronClient as default };
